@@ -5,4 +5,4 @@ from django.utils.translation import gettext_lazy as _
 class SalesmanOrdersApp(AppConfig):
     name = 'salesman.orders'
     label = 'salesmanorders'
-    verbose_name = _("Orders")
+    verbose_name = _("Salesman")
