@@ -16,6 +16,7 @@ from django.utils.translation import gettext_lazy as _
 
 from salesman.basket.models import Basket, BasketItem
 from salesman.conf import app_settings
+from salesman.core.typing import Product
 from salesman.core.utils import get_salesman_model
 from salesman.orders.status import BaseOrderStatus
 
@@ -126,6 +127,7 @@ class BaseOrder(ClusterableModel):
     extra_rows: Optional[list] = None
 
     _current_status = None
+    _cached_items: Optional[list[BaseOrderItem]] = None
 
     class Meta:
         abstract = True
@@ -202,7 +204,7 @@ class BaseOrder(ClusterableModel):
         if not hasattr(basket, 'total'):
             basket.update(request)
 
-        self.user = basket.owner
+        self.user = basket.user
         self.email = basket.extra.pop('email', '')
         self.shipping_address = basket.extra.pop('shipping_address', '')
         self.billing_address = basket.extra.pop('billing_address', '')
@@ -222,6 +224,14 @@ class BaseOrder(ClusterableModel):
             obj.populate_from_basket_item(item, request)
             obj.save()
 
+    def get_items(self) -> list[BaseOrderItem]:
+        """
+        Returns items from cache or stores new ones.
+        """
+        if self._cached_items is None:
+            self._cached_items = list(self.items.all())
+        return self._cached_items
+
     @classproperty
     def Status(cls) -> Type[BaseOrderStatus]:
         """
@@ -324,7 +334,7 @@ class BaseOrderItem(models.Model):
     # Generic relation to product (optional).
     product_content_type = models.ForeignKey(ContentType, models.SET_NULL, null=True)
     product_id = models.PositiveIntegerField(_("Product id"), null=True)
-    product = GenericForeignKey('product_content_type', 'product_id')
+    product: Product = GenericForeignKey('product_content_type', 'product_id')
 
     # Stored product serializer data at the moment of purchase.
     product_data = models.JSONField(_("Product data"), blank=True, default=dict)
